@@ -48,20 +48,20 @@ FROM {0}.`functional_alltypes`"""
 
 
 def test_isin_notin_in_select(con, db, alltypes, translate):
-    values = ['foo', 'bar']
+    values = {'foo', 'bar'}
     filtered = alltypes[alltypes.string_col.isin(values)]
     result = ibis.clickhouse.compile(filtered)
     expected = """SELECT *
 FROM {}.`functional_alltypes`
 WHERE `string_col` IN {}"""
-    assert result == expected.format(db.name, tuple(set(values)))
+    assert result == expected.format(db.name, tuple(values))
 
     filtered = alltypes[alltypes.string_col.notin(values)]
     result = ibis.clickhouse.compile(filtered)
     expected = """SELECT *
 FROM {}.`functional_alltypes`
 WHERE `string_col` NOT IN {}"""
-    assert result == expected.format(db.name, tuple(set(values)))
+    assert result == expected.format(db.name, tuple(values))
 
 
 def test_head(alltypes):
@@ -211,20 +211,6 @@ def test_scalar_exprs_no_table_refs(expr, expected):
     assert ibis.clickhouse.compile(expr) == expected
 
 
-def test_expr_list_no_table_refs():
-    exlist = ibis.api.expr_list(
-        [
-            ibis.literal(1).name('a'),
-            ibis.now().name('b'),
-            ibis.literal(2).log().name('c'),
-        ]
-    )
-    result = ibis.clickhouse.compile(exlist)
-    expected = """\
-SELECT 1 AS `a`, now() AS `b`, log(2) AS `c`"""
-    assert result == expected
-
-
 # TODO: use alltypes
 def test_isnull_case_expr_rewrite_failure(db, alltypes):
     # #172, case expression that was not being properly converted into an
