@@ -16,7 +16,6 @@ import toolz
 from pandas.api.types import DatetimeTZDtype
 from pandas.core.groupby import DataFrameGroupBy, SeriesGroupBy
 
-import ibis
 import ibis.common.exceptions as com
 import ibis.expr.datatypes as dt
 import ibis.expr.operations as ops
@@ -964,6 +963,22 @@ def execute_node_log_number_number(op, value, base, **kwargs):
     return math.log(value, base)
 
 
+@execute_node.register(ops.DropNa, pd.DataFrame)
+def execute_node_dropna_dataframe(op, df, **kwargs):
+    subset = [col.get_name() for col in op.subset] if op.subset else None
+    return df.dropna(how=op.how, subset=subset)
+
+
+@execute_node.register(ops.FillNa, pd.DataFrame, simple_types)
+def execute_node_fillna_dataframe_scalar(op, df, replacements, **kwargs):
+    return df.fillna(replacements)
+
+
+@execute_node.register(ops.FillNa, pd.DataFrame)
+def execute_node_fillna_dataframe_dict(op, df, **kwargs):
+    return df.fillna(op.replacements)
+
+
 @execute_node.register(ops.IfNull, pd.Series, simple_types)
 @execute_node.register(ops.IfNull, pd.Series, pd.Series)
 def execute_node_ifnull_series(op, value, replacement, **kwargs):
@@ -1040,15 +1055,6 @@ def execute_node_coalesce(op, values, **kwargs):
     return compute_row_reduction(coalesce, values)
 
 
-@execute_node.register(ops.ExpressionList, collections.abc.Sequence)
-def execute_node_expr_list(op, sequence, **kwargs):
-    # TODO: no true approx count distinct for pandas, so we use exact for now
-    columns = [e.get_name() for e in op.exprs]
-    schema = ibis.schema(list(zip(columns, (e.type() for e in op.exprs))))
-    data = {col: [execute(el, **kwargs)] for col, el in zip(columns, sequence)}
-    return schema.apply_to(pd.DataFrame(data, columns=columns))
-
-
 def wrap_case_result(raw, expr):
     """Wrap a CASE statement result in a Series and handle returning scalars.
 
