@@ -384,7 +384,7 @@ class ExprSimplifier:
                     lifted_root = self.lift(value_op.table)
 
             if can_lift and not block:
-                lifted_node = ops.TableColumn(node.name, lifted_root)
+                lifted_node = ops.TableColumn(lifted_root, node.name)
                 result = expr._factory(lifted_node, name=expr._name)
 
         return result
@@ -989,7 +989,7 @@ class ExprValidator:
 
     def _error_message(self, expr):
         return (
-            'The expression %s does not fully originate from '
+            'The expression "%s" does not fully originate from '
             'dependencies of the table expression.' % repr(expr)
         )
 
