@@ -15,7 +15,8 @@ import ibis.expr.operations as ops
 import ibis.expr.types as ir
 from ibis.common.exceptions import ExpressionError, RelationError
 from ibis.expr.types import ColumnExpr, TableExpr
-from ibis.tests.util import assert_equal
+from ibis.tests.expr.mocks import MockAlchemyBackend, MockBackend
+from ibis.tests.util import assert_equal, assert_pickle_roundtrip
 
 
 @pytest.fixture
@@ -69,7 +70,7 @@ def test_view_new_relation(table):
     # meaning when it comes to execution
     tview = table.view()
 
-    roots = tview._root_tables()
+    roots = tview.op().root_tables()
     assert len(roots) == 1
     assert roots[0] is tview.op()
 
@@ -159,10 +160,11 @@ def test_projection_invalid_root(table):
 def test_projection_unnamed_literal_interactive_blowup(con):
     # #147 and #153 alike
     table = con.table('functional_alltypes')
+    exprs = [table.bigint_col, ibis.literal(5)]
 
     with config.option_context('interactive', True):
         try:
-            table.select([table.bigint_col, ibis.literal(5)])
+            table.select(exprs)
         except Exception as e:
             assert 'named' in e.args[0]
 
@@ -528,10 +530,50 @@ def test_summary_expand_list(table):
 
     metric = table.g.group_concat().name('bar')
     result = table.aggregate([metric, summ])
-    expected = table.aggregate([metric] + summ.exprs())
+    expected = table.aggregate([metric] + summ)
     assert_equal(result, expected)
 
 
+def test_summary_prefix_suffix(table):
+    def get_names(exprs):
+        return [e.get_name() for e in exprs]
+
+    assert get_names(table.g.summary(prefix="string_")) == [
+        'string_count',
+        'string_nulls',
+        'string_uniques',
+    ]
+    assert get_names(table.g.summary(suffix="_string")) == [
+        'count_string',
+        'nulls_string',
+        'uniques_string',
+    ]
+    assert get_names(table.g.summary(prefix="pre_", suffix="_post")) == [
+        'pre_count_post',
+        'pre_nulls_post',
+        'pre_uniques_post',
+    ]
+
+    assert get_names(table.f.summary(prefix="float_")) == [
+        "float_count",
+        "float_nulls",
+        "float_min",
+        "float_max",
+        "float_sum",
+        "float_mean",
+        "float_approx_nunique",
+    ]
+    assert get_names(table.f.summary(suffix="_numeric")) == [
+        "count_numeric",
+        "nulls_numeric",
+        "min_numeric",
+        "max_numeric",
+        "sum_numeric",
+        "mean_numeric",
+        "approx_nunique_numeric",
+    ]
+
+
 @pytest.mark.xfail(raises=AssertionError, reason='NYT')
 def test_aggregate_invalid(table):
     # Pass a non-aggregation or non-scalar expr
@@ -561,15 +603,21 @@ def test_filter_aggregate_partial_pushdown(table):
     assert False
 
 
-def test_aggregate_post_predicate(table):
+@pytest.mark.parametrize(
+    "case_fn",
+    [
+        pytest.param(lambda t: t.f.sum(), id="non_boolean"),
+        pytest.param(lambda t: t.f > 2, id="non_scalar"),
+    ],
+)
+def test_aggregate_post_predicate(table, case_fn):
     # Test invalid having clause
     metrics = [table.f.sum().name('total')]
     by = ['g']
+    having = [case_fn(table)]
 
-    invalid_having_cases = [table.f.sum(), table.f > 2]
-    for case in invalid_having_cases:
-        with pytest.raises(com.ExpressionError):
-            table.aggregate(metrics, by=by, having=[case])
+    with pytest.raises(com.IbisTypeError):
+        table.aggregate(metrics, by=by, having=having)
 
 
 def test_group_by_having_api(table):
@@ -1006,7 +1054,10 @@ def test_join_invalid_expr_type(con):
     invalid_right = left.foo_id
     join_key = ['bar_id']
 
-    with pytest.raises(TypeError, match=type(invalid_right).__name__):
+    with pytest.raises(
+        NotImplementedError,
+        match=r'string __getitem__\[str\]',
+    ):
         left.inner_join(invalid_right, join_key)
 
 
@@ -1298,6 +1349,39 @@ def test_pickle_table_expr():
     assert t1.equals(t0)
 
 
+def test_pickle_table_node(table):
+    n0 = table.op()
+    assert_pickle_roundtrip(n0)
+
+
+def test_pickle_projection_node(table):
+    m = table.mutate(foo=table.f * 2)
+
+    def f(x):
+        return (x.foo * 2).name('bar')
+
+    node = m.projection([f, 'f']).op()
+
+    assert_pickle_roundtrip(node)
+
+
+def test_pickle_group_by(table):
+    m = table.mutate(foo=table.f * 2, bar=table.e / 2)
+    expr = m.group_by(lambda x: x.foo).size()
+    node = expr.op()
+
+    assert_pickle_roundtrip(node)
+
+
+def test_pickle_asof_join():
+    left = ibis.table([('time', 'int32'), ('value', 'double')])
+    right = ibis.table([('time', 'int32'), ('value2', 'double')])
+    joined = api.asof_join(left, right, 'time')
+    node = joined.op()
+
+    assert_pickle_roundtrip(node)
+
+
 def test_group_by_key_function():
     t = ibis.table([('a', 'timestamp'), ('b', 'string'), ('c', 'double')])
     expr = t.groupby(new_key=lambda t: t.b.length()).aggregate(foo=t.c.mean())
@@ -1321,3 +1405,23 @@ def test_mutate_chain():
     assert isinstance(a.op(), ops.IfNull)
     assert isinstance(b.op(), ops.TableColumn)
     assert isinstance(b.op().table.op().selections[1].op(), ops.IfNull)
+
+
+def test_multiple_dbcon():
+    """
+    Expr from multiple connections to same DB should be compatible.
+    """
+    con1 = MockBackend()
+    con2 = MockBackend()
+
+    con1.table('alltypes').union(con2.table('alltypes')).execute()
+
+
+@pytest.mark.xfail(
+    raises=RelationError, reason='Expr from different DB should fail #64'
+)
+def test_multiple_db():
+    con1 = MockBackend()
+    con2 = MockAlchemyBackend()
+
+    con1.table('alltypes').union(con2.table('alltypes')).execute()
