@@ -1,6 +1,7 @@
 import functools
 import operator
 import os
+import uuid
 from collections import OrderedDict
 from datetime import date, datetime, time
 from operator import methodcaller
@@ -34,8 +35,8 @@ def test_null():
     assert_equal(expr, expr2)
 
     assert expr is expr2
-    assert expr.type() is dt.null
-    assert expr2.type() is dt.null
+    assert expr.type().equals(dt.null)
+    assert expr2.type().equals(dt.null)
 
 
 @pytest.mark.xfail(
@@ -63,6 +64,7 @@ def test_unicode():
         (-2147483649, 'int64'),
         (1.5, 'double'),
         ('foo', 'string'),
+        (b'fooblob', 'binary'),
         ([1, 2, 3], 'array<int8>'),
     ],
 )
@@ -117,6 +119,8 @@ multipolygon1 = [polygon1, polygon2]
         (tuple(multipoint), 'multipoint'),
         (list(multipolygon1), 'multipolygon'),
         (tuple(multipolygon1), 'multipolygon'),
+        pytest.param(uuid.uuid4(), 'uuid', id='uuid'),
+        pytest.param(str(uuid.uuid4()), 'uuid', id='uuid_str'),
     ],
 )
 def test_literal_with_explicit_type(value, expected_type):
@@ -234,7 +238,7 @@ def test_literal_array():
 
 def test_mixed_arity(table):
     what = ["bar", table.g, "foo"]
-    expr = api.as_value_expr(what)
+    expr = api.sequence(what)
 
     values = expr.op().values
     assert isinstance(values[1], ir.StringColumn)
@@ -884,47 +888,6 @@ def test_string_add_concat():
     assert False
 
 
-@pytest.fixture
-def expr():
-    exprs = [ibis.literal(1).name('a'), ibis.literal(2).name('b')]
-
-    return ibis.expr_list(exprs)
-
-
-def test_names(expr):
-    assert expr.names() == ['a', 'b']
-
-
-def test_prefix(expr):
-    prefixed = expr.prefix('foo_')
-    result = prefixed.names()
-    assert result == ['foo_a', 'foo_b']
-
-
-def test_rename(expr):
-    renamed = expr.rename(lambda x: f'foo({x})')
-    result = renamed.names()
-    assert result == ['foo(a)', 'foo(b)']
-
-
-def test_suffix(expr):
-    suffixed = expr.suffix('.x')
-    result = suffixed.names()
-    assert result == ['a.x', 'b.x']
-
-
-def test_concat():
-    exprs = [ibis.literal(1).name('a'), ibis.literal(2).name('b')]
-    exprs2 = [ibis.literal(3).name('c'), ibis.literal(4).name('d')]
-
-    list1 = ibis.expr_list(exprs)
-    list2 = ibis.expr_list(exprs2)
-
-    result = list1.concat(list2)
-    expected = ibis.expr_list(exprs + exprs2)
-    assert_equal(result, expected)
-
-
 def test_substitute_dict():
     table = ibis.table([('foo', 'string'), ('bar', 'string')], 't1')
     subs = {'a': 'one', 'b': table.bar}
